%%
%% This is file `ieuthesis.cls',
%%
%% Izmir University of Economics
%% Graduate School of Natural and Applied Sciences
%% MS and PhD Thesis Style
%%
%% by Ugur Madran
%%
%% December 6, 2008
%% Rev: July 15, 2013
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ieuthesis}

% --- base class and extensions..
\LoadClass[12pt]{report}
\RequirePackage{graphicx}
\RequirePackage{setspace}

\makeatletter

%% -------- the following variables must be supplied
\def\director#1{\gdef\@director{#1}}
\def\head#1{\gdef\@head{#1}}
\def\thesistype#1{\gdef\@thesistype{#1}}
\def\teztipi#1{\gdef\@teztipi{#1}}

\def\keywords#1{\gdef\@keywords{#1}}
\def\anahtarsoz#1{\gdef\@anahtarsoz{#1}}

\def\dept#1{\gdef\@dept{#1}}
\def\bolum#1{\gdef\@bolum{#1}}
\def\tezyoneticisiA#1{\gdef\@tezyoneticisiA{#1}}
\def\tezyoneticisiB#1{\gdef\@tezyoneticisiB{#1}}
\gdef\advis@r{Supervisor}
\def\principaladvisor#1{\gdef\@principaladvisor{#1}}
\def\coadvisor#1{\gdef\@coadvisor{#1}}
\def\firstreader#1{\gdef\@firstreader{#1}}
\def\secondreader#1{\gdef\@secondreader{#1}}
% third and fourth reader are required in PhD only
\def\thirdreader#1{\gdef\@thirdreader{#1}}
\def\fourthreader#1{\gdef\@fourthreader{#1}}
\def\superaff#1{\gdef\@superaff{#1}}
\def\firstaff#1{\gdef\@firstaff{#1}}
\def\secondaff#1{\gdef\@secondaff{#1}}
\def\thirdaff#1{\gdef\@thirdaff{#1}}
\def\fourthaff#1{\gdef\@fourthaff{#1}}
\def\submitdate#1{\gdef\@submitdate{#1}}
\def\tarih#1{\gdef\@tarih{#1}}
\def\baslik#1{\gdef\@baslik{#1}}


%% height related measures
\voffset 0mm
\topmargin -5mm
\headsep 15mm
\textheight 220mm

%% width releatex measures
\hoffset 0mm
\textwidth 145mm
\oddsidemargin 0.6in \evensidemargin 0.6in
\marginparwidth 40pt \marginparsep 12pt

\parskip 0.166in \footskip 25pt
\tolerance=6000
\brokenpenalty=10000

\renewcommand{\baselinestretch}{1.3}
\renewcommand{\linespread}{1.3}

\def\thefigure{\thechapter.\@arabic\c@figure}
\def\thetable{\thechapter.\@arabic\c@table}
\def\theequation{\thechapter.\arabic{equation}}

\long\def\@footnotetext#1{\insert\footins{\def\baselinestretch{1}\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth \@parboxrestore
   \edef\@currentlabel{\csname p@footnote\endcsname\@thefnmark}\@makefntext
    {\rule{\z@}{\footnotesep}\ignorespaces
      #1\strut}}}

\def\@submitdate{\ifcase\the\month\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or December\fi
  \space \number\the\year}
\ifnum\month=12
    \@tempcnta=\year \advance\@tempcnta by 1
\fi

\def\titlepageMS{%
        % Front Cover
        \setcounter{page}{0}
        \thispagestyle{empty}%
        \null\vskip1in%
        \begin{center}
                {\Large\bf\uppercase\expandafter{\@title}}
        \end{center}
        \vfill
%        \vspace{3cm}
        \begin{center}
                {\large
                \uppercase\expandafter{\@author}
                \vfill
                \uppercase\expandafter{\@submitdate}\\
                }
        \end{center}\vskip.5in\newpage
        % Title Page
        \thispagestyle{empty}%
        \addcontentsline{toc}{chapter}{Front Matter}
        \null\vskip1in%
        \begin{center}
                {\Large\bf\uppercase\expandafter{\@title}}
        \end{center}
        \vfill
        \begin{center}
                {\large
                \sc a thesis
                submitted to \\ the graduate school of \\ natural
                and applied sciences of \\
%                department of \lowercase\expandafter{\@dept}\\
                izmir university of economics\\
                }
        \end{center}
        \vfill
%        \vspace{3cm}
        \begin{center}
                {\large
                {\sc by}\\
                \uppercase\expandafter{\@author}\\
                \vspace{3cm}
                {\sc
                in partial fulfillment of the requirements\\
                for the degree of\\
                master of science \\
                in the graduate school of natural and applied sciences\\
                }
                \vfill
                \uppercase\expandafter{\@submitdate}\\
                }
        \end{center}\vskip.5in\newpage}


\def\titlepagePhD{%
        % Front Cover
        \setcounter{page}{0}
        \thispagestyle{empty}%
        \null\vskip1in%
        \begin{center}
                {\Large\bf\uppercase\expandafter{\@title}}
        \end{center}
        \vfill
        \vspace{3cm}
        \begin{center}
                {\large
                \uppercase\expandafter{\@author}
                \vfill
                \uppercase\expandafter{\@submitdate}\\
                }
        \end{center}\vskip.5in\newpage
        % Title Page
        \thispagestyle{empty}%
        \addcontentsline{toc}{chapter}{Front Matter}
        \null\vskip1in%
        \begin{center}
                {\Large\bf\uppercase\expandafter{\@title}}
        \end{center}
        \vfill
        \begin{center}
                {\large
                \sc a dissertation submitted to \\
                the graduate school of natural \\
                and applied sciences
                of \\
%                department of \lowercase\expandafter{\@dept}\\
                izmir university of economics\\
                }
        \end{center}
        \vfill
%        \vspace{3cm}
        \begin{center}
                {\large
                {\sc by}\\
                \uppercase\expandafter{\@author}\\
                \vspace{3cm}
                {\sc
                in partial fulfillment of the requirements\\
                for the degree of
                doctor of philosophy \\
                in the graduate school of natural and applied sciences\\
                }
                \vfill
                \uppercase\expandafter{\@submitdate}\\
                }
        \end{center}\vskip.5in\newpage}


\def\signaturepageMS{%
% Approval page has no page number! January 9, 2009.
%        \thispagestyle{plain}
        \thispagestyle{empty}

% New format, January 3, 2009.
% Revision July 18, 2013.
{
\begin{center}
\bfseries M.S. THESIS EXAMINATION RESULT FORM
\end{center}
}

\noindent
Approval of the Graduate School of Natural and Applied Sciences
\begin{flushright}
        \vspace{.1in}
\begin{minipage}{2.5in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            \@director \\ Director}}
\end{minipage}
\end{flushright}

\vspace{.2in}
\noindent
I certify that this thesis satisfies all the requirements as a thesis for the degree of Master of Science.
\begin{flushright}
\begin{minipage}{2.5in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            \@head \\ Head of Department}}
\end{minipage}
\end{flushright}

\vspace{.2in}
\noindent
We have read the thesis entitled
{\bfseries ``{\@title}''}
completed by {\bfseries \@author}
under supervision of {\bfseries \@principaladvisor}
% and {\bfseries \@coadvisor}       % if available uncomment the line
and we certify that in our opinion it is
fully adequate, in scope and in quality, as a
thesis for the degree of Master of Science.

\noindent
%\begin{minipage}{2.5in}         % un/comment this block for coadvisor
%        \vspace{.2in}
%        {\shortstack{\vrule width 2.5in height 0.4pt\\
%            {\small\@coadvisor} \\ \small Co-\advis@r}}
%\end{minipage}
\hspace{\stretch{1}}
\begin{minipage}{2.5in}
        \vspace{.2in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            {\small\@principaladvisor} \\ \small\advis@r}}
\end{minipage}

\setlength{\unitlength}{1in}
\vspace{.1in}
\noindent
{\bfseries Examining Committee Members}\hfill {\bfseries Date:}\line(1,0){2}\\[1ex]
% Title and Name in alphabetical order of last name!
\@principaladvisor\\[-1ex]
\@superaff \hfill\line(1,0){2.5}\\[.1in]
\@firstreader\\[-1ex]
\@firstaff \hfill\line(1,0){2.5}\\[.1in]
\@secondreader\\[-1ex]
\@secondaff \hfill\line(1,0){2.5}%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% If coadvisor is also a jury member, than there should be 5 members!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\\[.1in]
%\@thirdreader\\[-1ex]
%\@thirdaff \hfill\line(1,0){2.5}\\[.1in]
%\@fourthreader\\[-1ex]
%\@fourthaff \hfill\line(1,0){2.5}

        \newpage}


\def\signaturepagePhD{%
% Approval page has no page number! January 9, 2009.
%        \thispagestyle{plain}
        \thispagestyle{empty}

% New format, January 3, 2009.
% Revision July 18, 2013.
{
\begin{center}
\bfseries Ph.D. DISSERTATION EXAMINATION RESULT FORM
\end{center}
}

\noindent
Approval of the Graduate School of Natural and Applied Sciences
\begin{flushright}
        \vspace{.1in}
\begin{minipage}{2.5in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            \@director \\ Director}}
\end{minipage}
\end{flushright}

\vspace{-.1in}
\noindent
I certify that this thesis satisfies all the requirements as a thesis for the degree of Doctor of Philosophy.
\begin{flushright}
\begin{minipage}{2.5in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            \@head \\ Head of Department}}
\end{minipage}
\end{flushright}

\vspace{.15in}
\noindent
We have read the dissertation entitled
{\bfseries ``{\@title}''}
completed by {\bfseries \@author}
under supervision of {\bfseries \@principaladvisor}
% and {\bfseries \@coadvisor}       % if available un/comment the line
and we certify that in our opinion it is
fully adequate, in scope and in quality, as a
dissertation for the degree of Doctor of Philosophy.

\noindent
%\begin{minipage}{2.5in}         % un/comment this block for coadvisor
%        \vspace{.2in}
%        {\shortstack{\vrule width 2.5in height 0.4pt\\
%            {\small\@coadvisor} \\ \small Co-\advis@r}}
%\end{minipage}
\hspace{\stretch{1}}
\begin{minipage}{2.5in}
        \vspace{.2in}
        {\shortstack{\vrule width 2.5in height 0.4pt\\
            {\small\@principaladvisor} \\ \small\advis@r}}
\end{minipage}

\setlength{\unitlength}{1in}
\vspace{.1in}
\noindent
{\bfseries Examining Committee Members}\hfill {\bfseries Date:}\line(1,0){2}\\[1ex]
% Title and Name in alphabetical order of first title than last name!
%\vspace{.4in}
\@principaladvisor\\[-1ex]
\@superaff \hfill\line(1,0){2.5}\\[.1in]
\@firstreader\\[-1ex]
\@firstaff \hfill\line(1,0){2.5}\\[.1in]
\@secondreader\\[-1ex]
\@secondaff \hfill\line(1,0){2.5}\\[.1in]
\@thirdreader\\[-1ex]
\@thirdaff \hfill\line(1,0){2.5}\\[.1in]
\@fourthreader\\[-1ex]
\@fourthaff \hfill\line(1,0){2.5}

%        \vspace*{1cm}
        \newpage}


\renewenvironment{abstract}{%
% Abstract page has a page number! January 9, 2009.
%        \thispagestyle{empty}
        \thispagestyle{plain}
% Abstract should appear in TOC! January 9, 2009.
\addcontentsline{toc}{section}{Abstract}
   \setlength{\baselineskip}{6mm}
   \begin{center}
     {\Large ABSTRACT} \\
     \vspace*{0.5cm}
     {\Large \uppercase\expandafter{\@title}} \\
     \vspace{0.5cm}
     \@author   \\
     \@thesistype  in \@dept \\
     Graduate School of Natural and Applied Sciences\\ %\\
     Supervisor: \@principaladvisor %\\
%     \\ Co-Supervisor: \@coadvisor       % un/comment for coadvisor
     \\ %\\
     \@submitdate \\
   \end{center}
  \noindent } {{\vfill \noindent {\em Keywords:} {\@keywords}.} \newpage}

\newenvironment{ozet}{%
% Abstract page has a page number! January 9, 2009.
%        \thispagestyle{empty}
        \thispagestyle{plain}
% Abstract should appear in TOC! January 9, 2009.
\addcontentsline{toc}{section}{\"{O}z}
   \setlength{\baselineskip}{6mm}
   \begin{center}
     {\Large \"{O}Z} \\
     \vspace*{0.5cm}
     {\Large \uppercase\expandafter{\@baslik}} \\
     \vspace{0.5cm}
     \@author   \\
     \@bolum, \@teztipi \\
     Fen Bilimleri Enstit\"{u}s\"{u} \\ %\\
     Tez Dan\i{}\c{s}man\i{}: \@tezyoneticisiA %
%     \\ \.{I}kinci Tez Dan\i{}\c{s}man\i{}: \@tezyoneticisiB      % un/comment if needed!
     \\
     \@tarih \\
   \end{center}
  \noindent} {{\vfill \noindent {\em Anahtar Kelimeler\/}: {\@anahtarsoz}.} \newpage}

\newenvironment{ack}{%
   \thispagestyle{plain}
% Abstract should appear in TOC! January 9, 2009.
\addcontentsline{toc}{section}{Acknowledgement}
   {\begin {center} {\bf \Large \bf \uppercase\expandafter{Acknowledgement}}\end{center}}
   \vspace{0.5cm} \noindent } {\newpage}

\newenvironment{dedication}{
   \thispagestyle{plain}
   \vspace*{40mm}
} {\newpage}

% Start with pagestyle{headings} in case front matter isn't processed
\pagestyle{headings}
\makeatother

\pagenumbering{roman}
% January 9, 2009.
\renewcommand{\contentsname}{\Large\uppercase{Table of Contents}}
\renewcommand{\listfigurename}{\Large\uppercase{List of Figures}}
\renewcommand{\listtablename}{\Large\uppercase{List of Tables}}
\renewcommand{\bibname}{\Large\uppercase{Bibliography}}
